gridgeo
-------

.. image:: https://travis-ci.org/pyoceans/gridgeo.svg?branch=master
    :target: https://travis-ci.org/pyoceans/gridgeo

.. image:: https://zenodo.org/badge/5715/pyoceans/gridgeo.svg
   :target: https://zenodo.org/badge/latestdoi/5715/pyoceans/gridgeo

Convert ocean numerical models grids,
including UGRID and SGRID compliant files,
to a variety of geo-like objects: GeoJSON, and shapefile.

For some usage examples check the notebook folder:

https://github.com/pyoceans/gridgeo/tree/master/notebooks